@@ -10,21 +10,28 @@ See https://cadet-process.readthedocs.io for complete documentation.
 """
 # Version information
 name = 'CADET-Process'
-__version__ = '0.5.2'
+__version__ = '0.6.0'
 
 # Imports
 from .CADETProcessError import *
 
+from . import settings
 from . import log
 from . import dataStructure
+from . import transform
 from . import plotting
-from . import common
 from . import dynamicEvents
 from . import processModel
-from . import modelBuilder
-from . import simulation
-from . import fractionation
+from . import solution
+from . import reference
+from .simulationResults import SimulationResults
+from . import metric
+from . import performance
 from . import optimization
-from . import evaluator
+from . import comparison
+from . import stationarity
+from . import simulator
+from . import fractionation
 from . import equilibria
+from . import modelBuilder
 
