@@ -5,12 +5,12 @@ from addict import Dict
 import numpy as np
 
 from CADETProcess import CADETProcessError
-from CADETProcess.common import settings
+from CADETProcess import settings
 from CADETProcess.dataStructure import String
 from CADETProcess.dynamicEvents import EventHandler
 from CADETProcess import plotting
-from CADETProcess.common import Performance
-from CADETProcess.simulation import SimulationResults
+from CADETProcess.performance import Performance
+from CADETProcess import SimulationResults
 
 from CADETProcess.fractionation.fractions import Fraction, FractionPool
 
@@ -64,6 +64,10 @@ class Fractionator(EventHandler):
 
         self.reset()
 
+    @property
+    def component_system(self):
+        return self.chromatograms[0].component_system
+
     def call_by_chrom_name(func):
         @wraps(func)
         def wrapper(self, chrom, *args, **kwargs):
@@ -115,8 +119,8 @@ class Fractionator(EventHandler):
         return chrom_events
 
     @property
-    def process_meta(self):
-        return self.simulation_results.process_meta
+    def process(self):
+        return self.simulation_results.process
 
     @property
     def n_comp(self):
@@ -126,7 +130,7 @@ class Fractionator(EventHandler):
     @property
     def cycle_time(self):
         """float: cycle time"""
-        return self.chromatograms[0].cycle_time
+        return self.process.cycle_time
 
     @property
     def time(self):
@@ -380,7 +384,7 @@ class Fractionator(EventHandler):
     def recovery(self):
         """ndarray: Component recovery yield in corresponding fraction pool."""
         with np.errstate(divide='ignore', invalid='ignore'):
-            recovery = self.mass / self.process_meta.m_feed
+            recovery = self.mass / self.process.m_feed
 
         return np.nan_to_num(recovery)
 
@@ -388,7 +392,7 @@ class Fractionator(EventHandler):
     def productivity(self):
         """ndarray: Specific productivity in corresponding fraction pool."""
         return self.mass / (
-            self.process_meta.cycle_time * self.process_meta.V_solid
+            self.cycle_time * self.process.V_solid
         )
 
     @property
@@ -401,14 +405,15 @@ class Fractionator(EventHandler):
             consumption. It is preferred here in order to avoid numeric issues
             if the collected mass is 0.
         """
-        return self.mass / self.process_meta.V_eluent
+        return self.mass / self.process.V_eluent
 
     @property
     def performance(self):
         self.reset()
         return Performance(
             self.mass, self.concentration, self.purity,
-            self.recovery, self.productivity, self.eluent_consumption
+            self.recovery, self.productivity, self.eluent_consumption,
+            self.component_system
         )
 
     def reset(self):
@@ -423,7 +428,7 @@ class Fractionator(EventHandler):
             chromatogram = self.chromatograms[0]
         elif isinstance(chromatogram, str):
             try:
-                chromatogram = self.chromatograms_dict[f"{chromatogram}/outlet"]
+                chromatogram = self.chromatograms_dict[f"{chromatogram}"]
             except KeyError:
                 raise CADETProcessError("Could not find chromatogram.")
         else:
@@ -530,7 +535,7 @@ class Fractionator(EventHandler):
         return self.parameters
 
     def save(self, case_dir, start=0, end=None):
-        path = os.path.join(settings.project_directory, case_dir)
+        path = os.path.join(settings.working_directory, case_dir)
 
         for index, chrom in enumerate(self.chromatograms):
             chrom.plot(save_path=path + f'/chrom_{index}.png')
@@ -545,3 +550,6 @@ class Fractionator(EventHandler):
                 save_path=path + f'/fractionation_signal_{index}.png',
                 index=index
             )
+
+    def __str__(self):
+        return self.__class__.__name__
