@@ -138,6 +138,8 @@ def set_layout(
         if show_legend and len(labels) != 0:
             ax.legend()
 
+    plt.tight_layout()
+
 
 class Tick(Structure):
     location: Tuple()
@@ -163,10 +165,15 @@ def add_text(ax, text):
     )
 
 
-def add_overlay(ax, overlay):
-    x = ax.lines[0].get_xdata()
-    for y_over in overlay:
-        ax.plot(x, y_over, linewidth=0.5, alpha=0.5)
+def add_overlay(ax, y_overlay, x_overlay=None, **plot_args):
+    if not isinstance(y_overlay, list):
+        y_overlay = [y_overlay]
+
+    if x_overlay is None:
+        x_overlay = ax.lines[0].get_xdata()
+
+    for y_over in y_overlay:
+        ax.plot(x_overlay, y_over, **plot_args)
         ax.set_prop_cycle(None)
 
 
@@ -256,13 +263,14 @@ def create_and_save_figure(func):
             fig, ax = setup_figure(style=style)
 
         artist = func(*args, ax=ax, **kwargs)
-        if show:
-            plt.show()
+
+        plt.tight_layout()
 
         if file_name is not None:
             plt.savefig(file_name)
 
-        plt.tight_layout()
+        if show:
+            plt.show()
 
         return artist
     return wrapper
